@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 use Code::TidyAll::Config::INI::Reader 0.44;
 use List::Util 1.45 qw( uniqstr );
@@ -52,7 +52,7 @@ my $perlcriticrc = <<'EOF';
 severity = 3
 verbose = 11
 theme = core + pbp + bugs + maintenance + cosmetic + complexity + security + tests + moose
-program-extensions = pl t
+program-extensions = pl psgi t
 
 exclude = Subroutines::ProhibitCallsToUndeclaredSubs
 
@@ -276,7 +276,7 @@ Dist::Zilla::Plugin::DROLSKY::TidyAll - Creates default tidyall.ini, perltidyrc,
 
 =head1 VERSION
 
-version 0.52
+version 0.53
 
 =for Pod::Coverage .*
 
